@@ -1,6 +1,9 @@
 #!/bin/sh
 #
-# Copyright 2020-2022 Univention GmbH
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2020-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,7 +34,7 @@ set -e
 t='/var/lib/univention-ldap/notify/transaction'
 if [ -s "$t" ] &&
 	[ -f /var/univention-join/joined ] &&
-	start-stop-daemon --status --pidfile /var/run/slapd/slapd.pid -x /usr/sbin/slapd &&
+	start-stop-daemon --status --pidfile /var/run/slapd/slapd.pid -x /usr/sbin/slapd -f /etc/ldap/slapd.conf &&
 	last="$(awk 'END{print $1}' "$t")" &&
 	! /usr/share/univention-directory-notifier/univention-translog ldap "$last" >/dev/null
 then
